Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Run ¶
func Run(cfg RunnerConfig)
Run starts the runner and listen the socket configured by environment variable "APISIX_LISTEN_ADDRESS"
Types ¶
type RunnerConfig ¶
type RunnerConfig struct {
// LogLevel is the level of log, default to `zapcore.InfoLevel`
LogLevel zapcore.Level
// LogOutput is the output of log, default to `os.Stdout`
LogOutput zapcore.WriteSyncer
}
RunnerConfig is the configuration of the runner
Click to show internal directories.
Click to hide internal directories.